/*
 * PanIndicator.java
 *
 * Created on April 5, 2006, 9:29 PM
 */

package com.penfieldrobotics.camview;

import javax.swing.*;
import java.awt.*;


public class PanIndicator extends JPanel {
    private int pan;
    private Dimension pSize;
    private Color fadeColor;
    private Color onTgtColor;

    // Center is 151
    private static final int PAN_CENTER = 151;
    private static final int PAN_ADJUST = 24;
    
    public PanIndicator() {
        pan = -1;
        fadeColor = Color.GREEN.darker();
        onTgtColor = Color.RED;
    }
    
    public void setPan(int pan) {
        this.pan = pan;
    }
    
    public void setFadeColor(Color c) {
        fadeColor = c;
    }

    public void setOnTgtColor(Color c) {
        onTgtColor = c;
    }
    
    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        Rectangle rect = g.getClipBounds();
        g.setColor(getBackground());
        g.fillRect(rect.x, rect.y, rect.width, rect.height);
        
        if (pan == -1)
            return;
        
        boolean inCenter;
        if (Math.abs(pan - PAN_CENTER) < CamView.PAN_CENTER_TOLERANCE)
            inCenter = true;
        else
            inCenter = false;
            
        
        float f = (pan - PAN_ADJUST) / 255.0f;
        f *= getWidth();
        int size = getHeight() - 8;
        int center = (int)f;
        
        int x = center - (size / 2);
        
        g.setColor(getIndicatorColor(Math.abs(getWidth()/2 - center), getWidth()/2));
        g.fillRect(x, 4, size, size);
        if (inCenter)
            g.setColor(onTgtColor);
        else
            g.setColor(getForeground());
        g.fillRect(x+size/4, 4+(size)/4, size/2, (size)/2);
        g.drawRect(x, 4, size-1, size-1);
        
    }
    
    private Color getIndicatorColor(int pos, int width) {
        float[] ocolors =  fadeColor.getRGBColorComponents(null);
        float[] fgcolors = getForeground().getRGBColorComponents(null);
        float[] diff = new float[3];
        float f = (float)pos / width;
        for (int i = 0; i < diff.length; ++i)
            diff[i] = Math.min(Math.max(0.0f, ocolors[i] + ((fgcolors[i] - ocolors[i]) * f)), 1.0f);
        
        return new Color(diff[0], diff[1], diff[2]);
    }
    
    public Dimension getPreferredSize() {
        if (pSize == null)
            return new Dimension(400, 50);
        else
            return pSize;
    }
    
    public void setPreferredSize(Dimension d) {
        pSize = d;
        super.setPreferredSize(d);
    }
    
}
